@@ -88,6 +88,7 @@ struct configuration_per_table{
   GHashTable *all_limit_per_table;
   GHashTable *all_num_threads_per_table;
   GHashTable *all_columns_on_select_per_table;
+  GHashTable *all_columns_on_select_replace_per_table;
   GHashTable *all_columns_on_insert_per_table;
   GHashTable *all_object_to_export;
   GHashTable *all_partition_regex_per_table;
@@ -103,7 +104,7 @@ struct M_ROW{
 #define STREAM_BUFFER_SIZE_NO_STREAM 100
 #define DEFAULTS_FILE "/etc/mydumper.cnf"
 struct function_pointer;
-typedef gchar * (*fun_ptr)(gchar **,gulong*, struct function_pointer*);
+typedef void (*fun_ptr)(GString *,gchar*,gulong*, struct function_pointer*);
 
 struct function_pointer{
   // use when writing
@@ -150,6 +151,9 @@ gchar **get_table_list(gchar *tables_list);
 void free_hash_table(GHashTable * hash);
 void remove_definer(GString * data);
 void remove_definer_from_gchar(char * str);
+void replace_definer_from_string(GString * data, char * _replace);
+void replace_definer_from_gchar (GString * output_data, char * str, char * _replace);
+void update_definer(GString *statement, gchar *replace_definer_str, gboolean skip_definer);
 void print_version(const gchar *program);
 gboolean stream_arguments_callback(const gchar *option_name,const gchar *value, gpointer data, GError **error);
 void initialize_set_names();
@@ -211,7 +215,7 @@ int global_process_create_table_statement (gchar * statement, GString *create_ta
 void initialize_conf_per_table(struct configuration_per_table *cpt);
 void parse_object_to_export(struct object_to_export *object_to_export,gchar *val);
 gchar *build_dbt_key(gchar *a, gchar *b);
-
+gchar *build_config_file_dbt_key(const gchar *a, const gchar *b);
 void discard_mysql_output(MYSQL *conn);
 gboolean m_query(  MYSQL *conn, const gchar *query, void log_fun(const char *, ...) , const char *fmt, ...);
 gboolean m_query_verbose(MYSQL *conn, const char *q, void log_fun(const char *, ...) , const char *fmt, ...);
@@ -230,4 +234,4 @@ void *monitor_throttling_thread (void *queue);
 gchar *set_names_statement_template(gchar *_set_names);
 void execute_set_names(MYSQL *conn, gchar *_set_names);
 gchar * common_build_schema_table_filename(gchar *_directory, char *database, char *table, const char *suffix);
-void load_options_for_product_from_key_file(GKeyFile *kf, GOptionContext *context, const gchar *app, int product, int major, int secondary, int revision);
+void load_options_for_product_from_key_file(GKeyFile *kf, GOptionContext *context, const gchar *app, int major, int secondary, int revision);
