@@ -46,8 +46,8 @@ void determine_show_table_status_columns(MYSQL_RES *result, guint *ecol, guint *
 void determine_explain_columns(MYSQL_RES *result, guint *rowscol);
 void determine_charset_and_coll_columns_from_show(MYSQL_RES *result, guint *charcol, guint *collcol);
 unsigned long m_real_escape_string(MYSQL *conn, char *to, const gchar *from, unsigned long length);
-void m_replace_char_with_char(gchar neddle, gchar replace, gchar *from, unsigned long length);
-void m_escape_char_with_char(gchar neddle, gchar replace, gchar *to, unsigned long length);
+void m_replace_char_with_char(gchar needle, gchar replace, gchar *str, unsigned long length);
+void m_escape_char_with_char(gchar needle, gchar replace, gchar *str, unsigned long length);
 void free_common();
 void initialize_sql_statement(GString *statement);
 void set_tidb_snapshot(MYSQL *conn);
@@ -59,4 +59,4 @@ extern guint nroutines;
 extern guint server_version;
 extern const char *routine_type[];
 void initialize_header_in_gstring(GString *statement, gchar *charset);
-
+gboolean m_pstrstr(char **str_list, const gchar* needle);
