@@ -14,22 +14,27 @@
 
         Authors:    David Ducos, Percona (david dot ducos at percona dot com)
 */
-#include <stdio.h>
+#ifndef _src_mydumper_database_h
+#define _src_mydumper_database_h
 
 struct database {
-  char *name;
-  char *filename;
-  char *escaped;
-  GMutex *ad_mutex;
-  gboolean already_dumped;
+  gchar *source_database;
+  gchar *source_database_escaped;
+  gchar *database_name_in_filename;
+//  GMutex *ad_mutex;
+//  gboolean already_dumped;
   gchar *schema_checksum;
   gchar *post_checksum;
   gchar *triggers_checksum;
+  gchar *events_checksum;
   gboolean dump_triggers;
 };
 
 void initialize_database();
-struct database * new_database(MYSQL *conn, char *database_name, gboolean already_dumped);
-gboolean get_database(MYSQL *conn, char *database_name, struct database ** database);
+//struct database * new_database(MYSQL *conn, char *database_name, gboolean already_dumped);
+struct database * get_database(MYSQL *conn, char *database_name, gboolean create_job);
 void free_databases();
 void write_database_on_disk(FILE *mdfile);
+// OPTIMIZATION: Unsorted version for faster finalization
+void write_database_on_disk_unsorted(FILE *mdfile);
+#endif
