@@ -62,7 +62,7 @@ GList *schema_post = NULL;
 gboolean it_is_a_consistent_backup = FALSE;
 GHashTable *all_dbts=NULL;
 char * (*identifier_quote_character_protect)(char *r);
-struct configuration_per_table conf_per_table = {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL};
+struct configuration_per_table conf_per_table = {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL};
 gboolean replica_stopped = FALSE;
 gboolean merge_dumpdir= FALSE;
 gboolean clear_dumpdir= FALSE;
@@ -401,7 +401,8 @@ MYSQL *create_main_connection(GOptionContext *context) {
   set_global = g_string_new(NULL);
   set_global_back = g_string_new(NULL);
   server_detect(conn);
-  load_options_for_product_from_key_file(key_file, context, "mydumper", get_product(), get_major(), get_secondary(), get_revision());
+  if (key_file)
+    load_options_for_product_from_key_file(key_file, context, "mydumper", get_major(), get_secondary(), get_revision());
   GHashTable * set_session_hash = mydumper_initialize_hash_of_session_variables();
   GHashTable * set_global_hash = g_hash_table_new ( g_str_hash, g_str_equal );
   if (key_file != NULL ){
@@ -664,13 +665,15 @@ void determine_ddl_lock_function(MYSQL ** conn, void(**acquire_global_lock_funct
       }
       break;
     case SERVER_TYPE_MARIADB:
-      if ((get_major() == 10 && get_secondary() >= 5) || get_major() > 10) {
+      if (((get_major() == 10 && get_secondary() >= 5) || get_major() > 10) && sync_thread_lock_mode!=FTWRL && !skip_ddl_locks ) {
+
         *acquire_ddl_lock_function = &send_mariadb_backup_locks;
 //            *release_ddl_lock_function = &send_backup_stage_end;
         *release_ddl_lock_function = NULL;
 
         *acquire_global_lock_function = &send_backup_stage_on_block_commit;
         *release_global_lock_function = &send_backup_stage_end;
+
       }else{
         default_locking( acquire_global_lock_function, release_global_lock_function, acquire_ddl_lock_function, release_ddl_lock_function, release_binlog_function);
       }
@@ -699,6 +702,8 @@ void print_dbt_on_metadata_gstring(struct db_table *dbt, GString *data){
   g_free(table);
   if (dbt->is_sequence)
     g_string_append_printf(data,"is_sequence = 1\n");
+  if (dbt->is_view)
+    g_string_append_printf(data,"is_view = 1\n");
   if (dbt->data_checksum)
     g_string_append_printf(data,"data_checksum = %s\n", dbt->data_checksum);
   if (dbt->schema_checksum)
@@ -901,13 +906,12 @@ void start_dump(struct configuration *conf, GOptionContext *context) {
   check_num_threads();
   g_message("Using %u dumper threads", num_threads);
 
-  initialize_connection(MYDUMPER);
-  conn = create_main_connection(context);
-
   initialize_start_dump();
   initialize_common();
   initialize_create_jobs(conf);
+  initialize_connection(MYDUMPER);
   initialize_masquerade();
+  conn = create_main_connection(context);
 
   /* Give ourselves an array of tables to dump */
   if (tables_list)
