@@ -39,6 +39,7 @@ enum sync_thread_lock_mode {
 struct MList{
   GList *list;
   GMutex *mutex;
+  guint count;  // Cached list length for O(1) access in hot paths
 };
 
 struct table_queuing {
@@ -74,8 +75,8 @@ struct configuration {
 #endif
 
 void load_start_dump_entries(GOptionContext *context, GOptionGroup * filter_group);
-void start_dump(struct configuration *conf);
-void *exec_thread(void *data);
+void start_dump(struct configuration *conf, GOptionContext *context);
+//void *exec_thread(void *data);
 gboolean sig_triggered_int(void * user_data);
 gboolean sig_triggered_term(void * user_data);
 void set_disk_limits(guint p_at, guint r_at);
