@@ -85,13 +85,12 @@ gboolean no_delete = FALSE;
 
 extern GHashTable *database_hash;
 extern gboolean shutdown_triggered;
-extern gboolean skip_definer;
 extern gboolean local_infile;
 extern guint64 max_transaction_size;
 
 const char DIRECTORY[] = "import";
 
-struct configuration_per_table conf_per_table = {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL};
+struct configuration_per_table conf_per_table = {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL};
 GHashTable * set_session_hash=NULL;
 
 GHashTable * myloader_initialize_hash_of_session_variables(){
@@ -249,6 +248,7 @@ void print_help(){
     print_string("set-names",set_names_in_conn_by_default);
 
     print_bool("skip-definer",skip_definer);
+    print_string("replace-definer",replace_definer);
     print_bool("help",help);
 
     print_string("directory",input_directory);
@@ -371,11 +371,6 @@ int main(int argc, char *argv[]) {
 
   check_num_threads();
 
-  if (num_threads > max_threads_per_table)
-    g_message("Using %u loader threads (%u per table)", num_threads, max_threads_per_table);
-  else
-    g_message("Using %u loader threads", num_threads);
-
   initialize_set_names();
 
   if (debug) {
@@ -401,6 +396,11 @@ int main(int argc, char *argv[]) {
 
   g_message("MyDumper restore version: %s", VERSION);
 
+  if (num_threads > max_threads_per_table)
+    g_message("Using %u loader threads (%u per table)", num_threads, max_threads_per_table);
+  else
+    g_message("Using %u loader threads", num_threads);
+
   // Starts modifying file in disk, creating objects and restore
 
   hide_password(argc, argv);
@@ -627,6 +627,11 @@ int main(int argc, char *argv[]) {
     execute_replication_commands(conn,replication_statements->change_replication_source->str);
   }
 
+  if (replication_statements->gtid_purge){
+    g_message("Sending GTID Purge");
+    execute_replication_commands(conn,replication_statements->gtid_purge->str);
+  }
+
   if (replication_statements->start_replica){
     g_message("Sending start replica");
     execute_replication_commands(conn,replication_statements->start_replica->str);
