@@ -36,7 +36,6 @@
 #include "myloader_database.h"
 #include "myloader_table.h"
 GHashTable *tbl_hash=NULL;
-int (*m_close)(void *file) = NULL;
 guint refresh_table_list_interval=100;
 guint refresh_table_list_counter=1;
 gboolean skip_table_sorting = FALSE;
@@ -44,6 +43,8 @@ gchar ** zstd_decompress_cmd = NULL;
 gchar ** gzip_decompress_cmd = NULL;
 guint max_number_tables_to_sort_in_table_list = 100000;
 
+extern gboolean for_channel_incompatibility;
+
 void initialize_common(){
   refresh_table_list_counter=refresh_table_list_interval;
   tbl_hash=g_hash_table_new ( g_str_hash, g_str_equal );
@@ -103,10 +104,21 @@ void remove_ignore_set_session_from_hash(){
     g_hash_table_remove(set_session_hash,l->data);
     l=l->next;
   }
-
-
 }
 
+gboolean should_ignore_set_statement(GString *data){
+  gboolean r=FALSE;
+  // Perf: Use data->len instead of strlen(data->str)
+  gchar *from_equal=g_strstr_len(data->str, data->len, "=");
+  if (from_equal && ignore_set_list ){
+    *from_equal='\0';
+    gchar * var_name=g_strrstr(data->str," ");
+    var_name++;
+    r=is_in_ignore_set_list(var_name);
+    *from_equal='=';
+  }
+  return r;
+}
 
 gchar *get_value(GKeyFile * kf,gchar *group, const gchar *_key){
   GError *error=NULL;
@@ -152,7 +164,7 @@ void change_master(GKeyFile * kf,gchar *group, struct replication_statements *rs
   gchar **keys=g_key_file_get_keys(kf,group, &len, &error);
   guint _exec_change_source=0, _exec_reset_replica=0, _exec_start_replica=0, _exec_start_replica_until=0;
 
-  gboolean _auto_position = FALSE;
+  gint _auto_position = -1;
   gboolean _source_ssl = FALSE;
   gchar *source_host = NULL;
   guint source_port = 3306;
@@ -182,7 +194,7 @@ void change_master(GKeyFile * kf,gchar *group, struct replication_statements *rs
         g_string_append_printf(traditional_change_source,", ");
       }
       if (!g_ascii_strcasecmp(keys[i], "SOURCE_AUTO_POSITION")){
-        _auto_position=g_ascii_strtoull(g_key_file_get_value(kf,group,keys[i],&error), NULL, 10)>0;
+        _auto_position=g_ascii_strtoull(g_key_file_get_value(kf,group,keys[i],&error), NULL, 10);
 //        g_string_append_printf(traditional_change_source, "%s = %d", (gchar *) keys[i], auto_position);
       } else if (!g_ascii_strcasecmp(keys[i], "SOURCE_SSL")){
         _source_ssl=g_ascii_strtoull(g_key_file_get_value(kf,group,keys[i],&error), NULL, 10)>0;
@@ -229,31 +241,36 @@ void change_master(GKeyFile * kf,gchar *group, struct replication_statements *rs
   if (_source_ssl)
     g_string_append_printf(traditional_change_source, "SOURCE_SSL = %d", _source_ssl);
 
-  if (_auto_position){
+  if (_auto_position>=0){
     g_string_append_printf(traditional_change_source, "SOURCE_AUTO_POSITION = %d", _auto_position);
-    g_string_append(aws_change_source,"CALL mysql.rds_set_external_master_with_auto_position");
+    if (_auto_position>0)
+      g_string_append(aws_change_source,"CALL mysql.rds_set_external_master_with_auto_position");
   }else
     g_string_append(aws_change_source,"CALL mysql.rds_set_external_master");
   
   g_string_append_printf(aws_change_source,"( %s, %d, %s, %s, ", source_host, source_port, source_user, source_password );
 
-  if (!_auto_position)
+  if (_auto_position>0)
     g_string_append_printf(aws_change_source,"%s, %"G_GINT64_FORMAT", %d, );\n", source_log_file, source_log_pos, _source_ssl);
   else
     g_string_append_printf(aws_change_source,"%d, 0);\n", _source_ssl);
 
   g_strfreev(keys);
-  g_string_append(traditional_change_source," FOR CHANNEL '");
-  if (channel_name!=NULL)
-    g_string_append(traditional_change_source,channel_name);
-  g_string_append(traditional_change_source,"';\n");
-
+  if (!for_channel_incompatibility){
+    g_string_append(traditional_change_source," FOR CHANNEL '");
+    if (channel_name!=NULL)
+      g_string_append(traditional_change_source,channel_name);
+    g_string_append(traditional_change_source,"';\n");
+  }
   if (set_gtid_purge){
     if (! rs->gtid_purge)
       rs->gtid_purge=g_string_new("");
-    if (source_control_command == TRADITIONAL)
+    if (source_control_command == TRADITIONAL){
+      if (get_product()==SERVER_TYPE_MARIADB)
+        g_string_append_printf(rs->gtid_purge, "%s;\nSET GLOBAL gtid_slave_pos=%s;\n", reset_replica, source_gtid);
+      else
       g_string_append_printf(rs->gtid_purge, "%s;\nSET GLOBAL gtid_purged=%s;\n", reset_replica, source_gtid);
-    else
+    }else
       g_string_append_printf(rs->gtid_purge, "CALL mysql.rds_gtid_purged (%s);\n", source_gtid);
   }
   if (_exec_reset_replica){
@@ -292,7 +309,7 @@ void change_master(GKeyFile * kf,gchar *group, struct replication_statements *rs
     if (source_gtid){
       g_string_append_printf(rs->start_replica_until,"SQL_AFTER_GTIDS = %s",source_gtid);
     }else{
-      g_string_append_printf(rs->start_replica_until,"SOURCE_LOG_FILE = '%s', SOURCE_LOG_POS = %"G_GINT64_FORMAT, source_log_file, source_log_pos);
+      g_string_append_printf(rs->start_replica_until,"SOURCE_LOG_FILE = %s, SOURCE_LOG_POS = %"G_GINT64_FORMAT, source_log_file, source_log_pos);
     }
     g_string_append(rs->start_replica_until," FOR CHANNEL '");
     if (channel_name!=NULL)
@@ -324,14 +341,31 @@ void change_master(GKeyFile * kf,gchar *group, struct replication_statements *rs
 }
 
 gboolean m_filename_has_suffix(gchar const *str, gchar const *suffix){
+  // Perf: Cache strlen results to avoid calling strlen 9x per invocation
+  // This function is called for every file in dump directory (~750K+ files for 250K tables)
+  gsize str_len = strlen(str);
+  gsize suffix_len = strlen(suffix);
+
   if (has_exec_per_thread_extension(str)){
-    return g_strstr_len(&(str[strlen(str)-strlen(exec_per_thread_extension)-strlen(suffix)]), strlen(str)-strlen(exec_per_thread_extension),suffix) != NULL;
+    gsize ext_len = strlen(exec_per_thread_extension);
+    if (str_len > ext_len + suffix_len) {
+      return g_strstr_len(&(str[str_len - ext_len - suffix_len]), str_len - ext_len, suffix) != NULL;
+    }
+    return FALSE;
   }else if ( g_str_has_suffix(str, GZIP_EXTENSION) ){
-    return g_strstr_len(&(str[strlen(str)-strlen(GZIP_EXTENSION)-strlen(suffix)]), strlen(str)-strlen(GZIP_EXTENSION),suffix) != NULL;
+    gsize ext_len = strlen(GZIP_EXTENSION);
+    if (str_len > ext_len + suffix_len) {
+      return g_strstr_len(&(str[str_len - ext_len - suffix_len]), str_len - ext_len, suffix) != NULL;
+    }
+    return FALSE;
   }else if ( g_str_has_suffix(str, ZSTD_EXTENSION) ){
-    return g_strstr_len(&(str[strlen(str)-strlen(ZSTD_EXTENSION)-strlen(suffix)]), strlen(str)-strlen(ZSTD_EXTENSION),suffix) != NULL;
+    gsize ext_len = strlen(ZSTD_EXTENSION);
+    if (str_len > ext_len + suffix_len) {
+      return g_strstr_len(&(str[str_len - ext_len - suffix_len]), str_len - ext_len, suffix) != NULL;
+    }
+    return FALSE;
   }
-  return g_str_has_suffix(str,suffix);
+  return g_str_has_suffix(str, suffix);
 }
 
 gboolean eval_table( char *db_name, char * table_name, GMutex * mutex){
