@@ -22,6 +22,9 @@
 #include <stdio.h>
 #include <string.h>
 #include <errno.h>
+#include <fcntl.h>
+#include <poll.h>
+#include <sys/wait.h>
 
 #include "myloader.h"
 #include "myloader_common.h"
@@ -34,11 +37,12 @@
 struct statement * new_statement();
 guint64 max_transaction_size=DEFAULT_MAX_TRANSACTION_SIZE;
 gboolean skip_definer = FALSE;
+gchar *replace_definer = NULL;
 GAsyncQueue *connection_pool = NULL;
 GAsyncQueue *restore_queues=NULL;
 GAsyncQueue *free_results_queue=NULL;
 int (*restore_data_from_file) (struct thread_data *, const char *, gboolean , struct database *) = NULL;
-
+gchar *replace_definer_str = NULL;
 GMutex *load_data_list_mutex=NULL;
 GHashTable * load_data_list = NULL;
 
@@ -58,10 +62,59 @@ struct io_restore_result end_restore_thread = { NULL, NULL};
 GThread **restore_threads=NULL;
 
 extern gchar *ignore_errors;
+/*
+// Issue #2075: Structure for background FIFO unlink thread
+struct fifo_unlink_data {
+  gchar *fifo_filename;
+  int child_pid;
+};
+
+// Issue #2075: Background thread that unlinks FIFO after confirming data is flowing
+// This ensures automatic cleanup on crash without affecting LOAD DATA operation
+static void *load_data_fifo_unlink_thread(void *data) {
+  struct fifo_unlink_data *fud = (struct fifo_unlink_data *)data;
+
+  // Wait a bit for MySQL to process the LOAD DATA statement and open the FIFO
+  // The decompressor subprocess blocks on write-open until MySQL opens for read
+  g_usleep(100000);  // 100ms - should be enough for MySQL to start processing
+
+  // Check if subprocess is still alive (means MySQL connected and data is flowing)
+  int status = 0;
+  pid_t result = waitpid(fud->child_pid, &status, WNOHANG);
+
+  if (result == 0) {
+    // Subprocess still running = MySQL must have connected (otherwise child would be blocked)
+    // Safe to unlink - the pipe stays usable through open file descriptors
+    if (remove(fud->fifo_filename) == 0) {
+      g_debug("Issue #2075: Unlinked LOAD DATA FIFO %s after MySQL connected", fud->fifo_filename);
+    }
+  } else {
+    // Subprocess already finished - MySQL read all data, FIFO will be cleaned up normally
+    g_debug("Issue #2075: Subprocess for %s already finished", fud->fifo_filename);
+  }
+
+  g_free(fud->fifo_filename);
+  g_free(fud);
+  return NULL;
+}
+
+
+// Issue #2075: Start background thread to unlink LOAD DATA FIFO
+static void schedule_load_data_fifo_unlink(const gchar *fifo_filename, int child_pid) {
+  struct fifo_unlink_data *fud = g_new0(struct fifo_unlink_data, 1);
+  fud->fifo_filename = g_strdup(fifo_filename);
+  fud->child_pid = child_pid;
+
+  // Spawn detached thread - it will clean itself up
+  g_thread_new("fifo_unlink", load_data_fifo_unlink_thread, fud);
+}
+*/
 
 void initialize_restore(){
   load_data_list_mutex=g_mutex_new();
   load_data_list = g_hash_table_new ( g_str_hash, g_str_equal );
+  if (replace_definer)
+    replace_definer_str=g_strdup_printf("DEFINER=%s",replace_definer);
 }
 
 struct connection_data *new_connection_data(MYSQL *thrconn){
@@ -209,7 +262,7 @@ struct connection_data *wait_for_available_restore_thread(struct thread_data *td
 
 extern gboolean control_job_ended;
 gboolean request_another_connection(struct thread_data *td, struct io_restore_result *io_restore_result, gboolean start_transaction, struct database *use_database, GString *header){
-  if ( control_job_ended && td->granted_connections < td->dbt->max_threads && g_list_length(td->dbt->restore_job_list)==0 ){
+  if ( control_job_ended && td->granted_connections < td->dbt->max_threads && td->dbt->count == 0 ){  // Perf: Use cached count
     g_assert(header);
     struct connection_data *cd=g_async_queue_try_pop(connection_pool);
     if(cd){
@@ -233,32 +286,47 @@ int m_commit_and_start_transaction(struct connection_data *cd, guint* query_coun
   return 0;
 }
 
-int restore_insert(struct connection_data *cd, struct thread_data*td, 
+int restore_insert(struct connection_data *cd, struct thread_data*td,
                   GString *data, guint *query_counter, guint offset_line, struct db_table *dbt)
 {
-  char *next_line=g_strstr_len(data->str,-1,"VALUES") + 6;
-  char *insert_statement_prefix=g_strndup(data->str,next_line - data->str);
+  // Perf: Find "VALUES" using strstr (only once, not in hot loop)
+  char *next_line=strstr(data->str, "VALUES");
+  if (next_line == NULL) return 0;
+  next_line += 6;  // Skip past "VALUES"
+
+  guint prefix_len = next_line - data->str;
+  char *insert_statement_prefix=g_strndup(data->str, prefix_len);
   int r=0;
   guint tr=0,current_offset_line=offset_line-1;
   gchar *current_line=next_line;
-  next_line=g_strstr_len(current_line, -1, "\n");
-  GString * new_insert=g_string_sized_new(strlen(insert_statement_prefix) + 65536);
+
+  // Perf: Calculate remaining length for bounded searches
+  gchar *data_end = data->str + data->len;
+  gssize remaining = data_end - current_line;
+
+  // Perf: Use memchr instead of g_strstr_len for newline search (SIMD-optimized)
+  next_line = (remaining > 0) ? memchr(current_line, '\n', remaining) : NULL;
+
+  GString * new_insert=g_string_sized_new(prefix_len + 4096);  // Larger initial size
   guint current_rows=0;
   guint64 transaction_size=0;
   do {
     current_rows=0;
     g_string_set_size(new_insert, 0);
     g_string_printf(new_insert,"/* Completed: %"G_GUINT64_FORMAT"%% */ ", dbt->rows>0?dbt->rows_inserted*100/dbt->rows:0);
-    new_insert=g_string_append(new_insert,insert_statement_prefix);
+    // Perf: Use append_len with known prefix length
+    g_string_append_len(new_insert, insert_statement_prefix, prefix_len);
     guint line_len=0;
     do {
-      char *line=g_strndup(current_line, next_line - current_line);
-      line_len=strlen(line);
-      g_string_append(new_insert, line);
-      g_free(line);
+      // Perf: Direct append without g_strndup + strlen + g_free
+      // The length is already known: next_line - current_line
+      line_len = next_line - current_line;
+      g_string_append_len(new_insert, current_line, line_len);
       current_rows++;
       current_line=next_line+1;
-      next_line=g_strstr_len(current_line, -1, "\n");
+      // Perf: Update remaining length and use memchr (16-32x faster than g_strstr_len)
+      remaining = data_end - current_line;
+      next_line = (remaining > 0) ? memchr(current_line, '\n', remaining) : NULL;
       current_offset_line++;
     } while ((rows == 0 || current_rows < rows) && next_line != NULL);
     if (current_rows > 1 || (current_rows==1 && line_len>0) ){
@@ -281,7 +349,7 @@ int restore_insert(struct connection_data *cd, struct thread_data*td,
         g_error("Thread %d with connection %ld: Error occurs between lines: %d and %d in a splited INSERT: %s",td->thread_id, cd->connection_id, offset_line,current_offset_line,mysql_error(cd->thrconn));
       }
       if (mysql_warning_count(cd->thrconn)){
-        g_warning("Connection %ld: Warnings found during INSERT between lines: %d and %d: %s",cd->connection_id, offset_line,current_offset_line, show_warnings_if_possible(cd->thrconn));
+        g_warning("Thread %d with connection %ld: Warnings found during INSERT between lines: %d and %d: %s",td->thread_id, cd->connection_id, offset_line,current_offset_line, show_warnings_if_possible(cd->thrconn));
         detailed_errors.data_warnings+=mysql_warning_count(cd->thrconn);
       }
     }else
@@ -519,9 +587,7 @@ int restore_data_from_mysqldump_file(struct thread_data *td, const char *filenam
         preline=line+1;
         g_string_set_size(data, 0);
       }else if (g_strrstr(&data->str[data->len >= 5 ? data->len - 5 : 0], delimiter)) {
-        if ( skip_definer && g_str_has_prefix(data->str,"CREATE")){
-          remove_definer(data);
-        }
+        update_definer(data, replace_definer_str, skip_definer);
         assign_statement(ir,td, td->dbt,data->str, preline, is_schema, OTHER);
         g_async_queue_push(cd->queue->restore,ir);
         ir=NULL;
@@ -594,8 +660,11 @@ int restore_data_from_mydumper_file(struct thread_data *td, const char *filename
   while (eof == FALSE) {
     if (read_data(infile, data, &eof, &line)) {
       if (g_strrstr(&data->str[data->len >= 5 ? data->len - 5 : 0], ";\n")) {
-        if ( skip_definer && g_str_has_prefix(data->str,"CREATE")){
-          remove_definer(data);
+        if (g_str_has_prefix(data->str,"CREATE")){
+          if ( skip_definer)
+            remove_definer(data);
+          if ( replace_definer_str )
+            replace_definer_from_string(data, replace_definer_str);
         }
         if ( g_strrstr_len(data->str,6,"INSERT")){
           request_another_connection(td, cd->queue, cd->transaction, use_database, header);
@@ -613,27 +682,36 @@ int restore_data_from_mydumper_file(struct thread_data *td, const char *filename
           process_result_statement(cd->queue->result, &ir, m_critical, "(2)Error occurs processing file %s", filename);
         }else if (g_strrstr_len(data->str,10,"LOAD DATA ")){
           GString *new_data = NULL;
-          gchar *from = g_strstr_len(data->str, -1, "'");
+          // Perf: Use strchr instead of g_strstr_len for single-char search
+          gchar *from = strchr(data->str, '\'');
+          if (from == NULL) goto STMT_IGNORED;
           from++;
-          gchar *to = g_strstr_len(from, -1, "'");
+          gchar *to = strchr(from, '\'');
+          if (to == NULL) goto STMT_IGNORED;
           load_data_filename=g_strndup(from, to-from);
           /* Wait for .dat file to be available (in streaming mode) */
           load_data_mutex_locate(load_data_filename);
           gchar **command=NULL;
+//          int load_data_child_pid = 0;  // Issue #2075: Track subprocess for FIFO unlink
           gboolean is_fifo = get_command_and_basename(load_data_filename, &command, &load_data_fifo_filename);
-          if (is_fifo){ 
+          if (is_fifo){
             if (fifo_directory != NULL){
               new_data = g_string_new_len(data->str, from - data->str);
               g_string_append(new_data, fifo_directory);
               g_string_append_c(new_data, '/');
               g_string_append(new_data, from);
-              from = g_strstr_len(new_data->str, -1, "'") + 1;
+              // Perf: Use strchr instead of g_strstr_len for single-char search
+              from = strchr(new_data->str, '\'');
+              if (from) from++;
               g_string_free(data, TRUE);
               data=new_data;
-              to = g_strstr_len(from, -1, "'");
+              to = from ? strchr(from, '\'') : NULL;
             }
+            // Perf: Cache strlen results instead of calling twice
+            guint load_data_filename_len = strlen(load_data_filename);
+            guint load_data_fifo_filename_len = strlen(load_data_fifo_filename);
             guint a=0;
-            for(;a<strlen(load_data_filename)-strlen(load_data_fifo_filename);a++){
+            for(;a<load_data_filename_len-load_data_fifo_filename_len;a++){
               *to=' '; to--;
             }
             *to='\'';
@@ -646,6 +724,7 @@ int restore_data_from_mydumper_file(struct thread_data *td, const char *filename
             if (mkfifo(load_data_fifo_filename,0666)){
               g_critical("cannot create named pipe %s (%d)", load_data_fifo_filename, errno);
             }
+            //load_data_child_pid = 
             execute_file_per_thread(load_data_filename, load_data_fifo_filename, command );
             release_load_data_as_it_is_close(load_data_fifo_filename);
 //              g_free(fifo_name);
@@ -653,15 +732,32 @@ int restore_data_from_mydumper_file(struct thread_data *td, const char *filename
 
           assign_statement(ir, td, td->dbt, data->str, preline, FALSE, OTHER);
           g_async_queue_push(cd->queue->restore,ir);
+
+          /*
+          // Issue #2075: Schedule background thread to unlink FIFO after MySQL connects
+          // This ensures automatic cleanup on crash without affecting LOAD DATA operation
+          if (is_fifo) {
+            schedule_load_data_fifo_unlink(load_data_fifo_filename, load_data_child_pid);
+          }
+          */
           ir=NULL;
           process_result_statement(cd->queue->result, &ir, m_critical, "(2)Error occurs processing file %s", filename);
-          if (is_fifo) 
+          if (is_fifo){
+            if (stream && !no_delete) 
+              g_unlink(load_data_filename);
             m_remove0(NULL, load_data_fifo_filename);
-          else
+          }else
             m_remove(NULL, load_data_filename);
         }else{
           if (g_strrstr_len(data->str,3,"/*!")){
-            gchar *from_equal=g_strstr_len(data->str, strlen(data->str),"=");
+            // Perf: Use data->len instead of strlen(data->str)
+            if (should_ignore_set_statement(data)){
+              goto STMT_IGNORED;
+            }else{
+              g_string_append(header,data->str);
+            }
+            /*
+            gchar *from_equal=g_strstr_len(data->str, data->len, "=");
             if (from_equal && ignore_set_list ){
               *from_equal='\0';
               gchar * var_name=g_strrstr(data->str," ");
@@ -676,6 +772,7 @@ int restore_data_from_mydumper_file(struct thread_data *td, const char *filename
             }else{
               g_string_append(header,data->str);
             }
+            */
           }else{
             header=NULL;
           }
