@@ -36,7 +36,7 @@ int get_major();
 int get_secondary();
 int get_revision();
 gboolean is_mysql_like();
-const gchar * get_product_name();
+const gchar * get_product_name(void);
 #endif
 
 
